# ╭──────╮
# │ tmux │
# ╰──────╯

# ╭──────┬───────╮
# │ tmux │ setup │
# ╰──────┴───────╯

rwx_tmux_setup() {
	local file script
	file="${HOME}/.tmux.conf"
	script="${HOME}/.tmux.sh"
	rwx_file_write "${script}" "\
rwx_tmux_server() {
	basename \"\${TMUX}\" |
		cut \\
		--delimiter \",\" \\
		--fields \"1\"
}
rwx_tmux_servers() {
	local active=\"\$(rwx_tmux_server)\"
	local ifs=\"\${IFS}\"
	local name path text
	local paths=\"\$(lsof -U |
		awk \"/^tmux:.*\\(LISTEN\\)\$/ {print \\\$9}\")\"
	IFS=\"
\"
	for path in \${paths}; do
		name=\"\$(basename \"\${path}\")\"
		text=\"\${text}\\
#[fg=default]\\
#[bg=default] \\
\"
		if [ \"\${active}\" = \"\${name}\" ]; then
			text=\"\${text}#[fg=green]\"
		else
			text=\"\${text}#[fg=yellow]\"
		fi
		text=\"\${text}\\
#[bg=##181818] \\
#[bg=##282828]\${name}\\
#[bg=##181818] \\
\"
	done
	IFS=\"\${ifs}\"
	echo \"\${text}\"
}
rwx_tmux_status() {
	local current=\"\${1}\"
	local operand=\"\${2}\"
	case \"\${operand}\" in
	\"+\")
		case \"\${current}\" in
		\"off\") current=\"on\" ;;
		\"on\") current=\"2\" ;;
		\"2\") current=\"3\" ;;
		\"3\") current=\"4\" ;;
		\"4\") current=\"5\" ;;
		*) ;;
		esac
		;;
	\"-\")
		case \"\${current}\" in
		\"on\") current=\"off\" ;;
		\"2\") current=\"on\" ;;
		\"3\") current=\"2\" ;;
		\"4\") current=\"3\" ;;
		\"5\") current=\"4\" ;;
		*) ;;
		esac
		;;
	*) ;;
	esac
	tmux set-option -g status \"\${current}\"
}
rwx_tmux_uptime() {
	local since=\"\$(uptime --since)\"
	local date=\"\$(echo \"\${since}\" | awk '{print \$1}')\"
	local time=\"\$(echo \"\${since}\" | awk '{print \$2}')\"
	echo \"\\
#[fg=yellow]\\
#[bg=##181818] \\
#[bg=##282828]\${date}\\
#[bg=##181818] \\
#[fg=default]\\
#[bg=default] \\
#[fg=yellow]\\
#[bg=##181818] \\
#[bg=##282828]\${time}\\
#[bg=##181818] \\
\"
}
"
	rwx_file_write "${file}" "\
# ╭────────╮
# │ option │
# ╰────────╯

# empty name for windows
set-option -g automatic-rename-format '#{pane_current_command}'
set-option -g automatic-rename on

# first index number
set-option -g base-index 1

# display duration
set-option -g display-time 1536

# extend history limit
set-option -g history-limit 1048576

# style for messages
set-option -g message-style bg=red,fg=white

# activity monitoring
set-window-option -g monitor-activity on

# silence monitoring
set-window-option -g monitor-silence 0

# enable mouse actions
set-option -g mouse on

# prefix with ^B or F12
set-option -g prefix C-b
set-option -g prefix2 F12

# renumber windows after closing one
set-option -g renumber-windows on

# enable title
set-option -g set-titles on

# set title to working directory
set-option -g set-titles-string '\
#(sh -c \". ${script}; rwx_tmux_server\")\
 / \
#{session_name}\
 / \
#{window_name}\
 / \
#{pane_current_command}\
 - \
#{window_width}×#{window_height}\
 / \
#{pane_width}×#{pane_height}\
'

# ╭────────┬──────╮
# │ option │ pane │
# ╰────────┴──────╯

# first index number
set-option -g pane-base-index 1

# ╭────────┬──────┬────────╮
# │ option │ pane │ border │
# ╰────────┴──────┴────────╯

# active style
set-option -g pane-active-border-style fg=green

# regular style
set-option -g pane-border-style fg=blue

# ╭────────┬────────╮
# │ option │ status │
# ╰────────┴────────╯

# status lines
set-option -g status 2

# background color
set-option -g status-bg '#080808'

# foreground color
set-option -g status-fg white

# line 1
set-option -g status-format[0] '\
#{W:\
#{?window_active,#[fg=green],\
#{?window_activity_flag,#[fg=red],#[fg=yellow]}}\
#[bg=##181818]#{?window_zoomed_flag,#[fg=magenta][, }\
#[bg=##282828]#{window_name}\
#[bg=##181818]#{?window_zoomed_flag,#[fg=magenta]], }\
#[fg=default]\
#[bg=default] \
} \
\
#[align=right]\
#[fg=yellow]\
#[bg=##181818] \
#[bg=##282828]%Y-%m-%d\
#[bg=##181818] \
#[fg=default]\
#[bg=default] \
#[fg=yellow]\
#[bg=##181818] \
#[bg=##282828]%H:%M:%S\
#[bg=##181818]#{?client_prefix,#[fg=green]p, }\
'

# line 2
set-option -g status-format[1] '\
#{S:\
#{?session_many_attached,#[fg=red],\
#{?session_attached,#[fg=green],#[fg=yellow]}}\
#[bg=##181818] \
#[bg=##282828]#{session_name}\
#[bg=##181818] \
#[fg=default]\
#[bg=default] \
} \
\
#[align=right]\
#(sh -c \". ${script}; rwx_tmux_servers\")\
'

# line 3
set-option -g status-format[2] '\
#[fg=cyan]#{pane_current_path}\
#[fg=default]\
#[bg=default]  \
\
#[align=right]\
'

# line 4
set-option -g status-format[3] '\
#{P:\
#{?pane_active,#[fg=green],#[fg=yellow]}\
#[bg=##181818] \
#[bg=##282828]#{pane_current_command}\
#[bg=##181818] \
#[fg=default]\
#[bg=default] \
} \
\
#[align=right]\
#(sh -c \". ${script}; rwx_tmux_uptime\")\
'

# line 5
set-option -g status-format[4] '\
#{P:\
#{?pane_active,#[fg=green],#[fg=yellow]}\
#[bg=##181818] \
#[bg=##282828]#{pane_width}×#{pane_height}\
#[bg=##181818] \
#[fg=default]\
#[bg=default] \
} \
\
#[align=right]\
#{?uid,#[fg=green],#[fg=red]}\
#[bg=##181818] \
#[bg=##282828]#{user}\
#[bg=##181818] \
#[fg=default]\
#[bg=default] \
#[fg=yellow]\
#[bg=##181818] \
#[bg=##282828]#{host}\
#[bg=##181818] \
'

# refresh period
set-option -g status-interval 1

# bar location
set-option -g status-position bottom

# ╭─────╮
# │ key │
# ╰─────╯

# detach client
bind-key -n F6 detach-client

# new
bind-key -n S-M-Down new-session
bind-key -n S-M-Right new-window

# select pane
bind-key -n C-S-Down select-pane -D
bind-key -n C-S-Left select-pane -L
bind-key -n C-S-Right select-pane -R
bind-key -n C-S-Up select-pane -U

# status lines
bind-key -n C-F6 set-option -g status off
bind-key -n C-F1 set-option -g status on
bind-key -n C-F2 set-option -g status 2
bind-key -n C-F3 set-option -g status 3
bind-key -n C-F4 set-option -g status 4
bind-key -n C-F5 set-option -g status 5
bind-key -n M-NPage run-shell '. ${script}; rwx_tmux_status #{status} -'
bind-key -n M-PPage run-shell '. ${script}; rwx_tmux_status #{status} +'

# switch session
bind-key -n M-Down switch-client -n
bind-key -n M-Up switch-client -p

# switch window
bind-key -n M-Left previous-window
bind-key -n M-Right next-window

# ╭─────┬────────╮
# │ key │ prefix │
# ╰─────┴────────╯

# rename
bind-key C-s command-prompt { rename-session '%%' }
bind-key C-w command-prompt { rename-window '%%' }

# split window
bind-key h split-window -c '#{pane_current_path}' -h
bind-key v split-window -c '#{pane_current_path}' -v

# kill server
bind-key k kill-server

# reload configuration
bind-key r source-file ${file} \\; display-message 'source-file ${file}'

# toggle mouse
bind-key t set-option -g mouse \\; display-message 'mouse = #{mouse}'

# swap window
bind-key M-Left swap-window -t -1
bind-key M-Right swap-window -t +1

#                                           ╭─────────────╮
#                                           │ default     │
#                     ╭───────────┬─────────┼─────┬───────┤
#                     │ -n        │ F12     │ -n  │ C-b   │
# ╭───────────────────┼───────────┼─────────┼─────┼───────┤
# │ command-prompt    │           │         │     │ :     │
# │ copy-mode         │           │         │     │ PPage │
# │ detach-client     │ F6        │         │     │ d     │
# │ kill-server       │           │ k       │     │       │
# │ new-session       │           │         │     │       │
# │ new-window        │ F2        │         │     │ c     │
# │ next-window       │ M-Right   │         │     │ n     │
# │ previous-window   │ M-Left    │         │     │ p     │
# │ rename-session    │           │ C-s     │     │       │
# │ rename-window     │           │ C-w     │     │       │
# │ resize-pane -Z    │           │         │     │ z     │
# │ select-pane -D    │ C-S-Down  │         │     │       │
# │ select-pane -L    │ C-S-Left  │         │     │       │
# │ select-pane -R    │ C-S-Right │         │     │       │
# │ select-pane -U    │ C-S-Up    │         │     │       │
# │ set -g mouse      │           │ t       │     │       │
# │ set -g status off │ C-F6      │         │     │       │
# │ set -g status on  │ C-F1      │         │     │       │
# │ set -g status 2   │ C-F2      │         │     │       │
# │ set -g status 3   │ C-F3      │         │     │       │
# │ set -g status 4   │ C-F4      │         │     │       │
# │ set -g status 5   │ C-F5      │         │     │       │
# │ source-file       │           │ r       │     │       │
# │ split-window -h   │           │ h       │     │ %     │
# │ split-window -v   │           │ v       │     │ \"     │
# │ swap-window -t -1 │           │ M-Left  │     │       │
# │ swap-window -t +1 │           │ M-Right │     │       │
# │ switch-client -n  │ M-Down    │         │     │       │
# │ switch-client -p  │ M-Up      │         │     │       │
# ╰───────────────────┴───────────┴─────────┴─────┴───────╯
"
}
